@@ -14,9 +14,9 @@ __PACKAGE__->add_columns(
   "error_disable_cause",
   { data_type => "text", is_nullable => 1 },
   "remote_is_wap",
-  { data_type => "boolean", is_nullable => 1 },
+  { data_type => "boolean", default_value => \"false", is_nullable => 1 },
   "remote_is_phone",
-  { data_type => "boolean", is_nullable => 1 },
+  { data_type => "boolean", default_value => \"false", is_nullable => 1 },
   "remote_vendor",
   { data_type => "text", is_nullable => 1 },
   "remote_model",
@@ -26,9 +26,9 @@ __PACKAGE__->add_columns(
   "remote_serial",
   { data_type => "text", is_nullable => 1 },
   "raw_speed",
-  { data_type => "bigint", is_nullable => 1 },
+  { data_type => "bigint", default_value => 0, is_nullable => 1 },
   "faststart",
-  { data_type => "boolean", is_nullable => 1 },
+  { data_type => "boolean", default_value => \"false", is_nullable => 1 },
   "ifindex",
   { data_type => "bigint", is_nullable => 1 },
 );
